@@ -12,6 +12,7 @@ Usage::
         ConversionTaskCompletedWaiter,
         ConversionTaskDeletedWaiter,
         CustomerGatewayAvailableWaiter,
+        DescribeAddressesAttributePaginator,
         DescribeByoipCidrsPaginator,
         DescribeCapacityReservationsPaginator,
         DescribeCarrierGatewaysPaginator,
@@ -182,6 +183,7 @@ Usage::
     vpn_connection_available_waiter: VpnConnectionAvailableWaiter = client.get_waiter("vpn_connection_available")
     vpn_connection_deleted_waiter: VpnConnectionDeletedWaiter = client.get_waiter("vpn_connection_deleted")
 
+    describe_addresses_attribute_paginator: DescribeAddressesAttributePaginator = client.get_paginator("describe_addresses_attribute")
     describe_byoip_cidrs_paginator: DescribeByoipCidrsPaginator = client.get_paginator("describe_byoip_cidrs")
     describe_capacity_reservations_paginator: DescribeCapacityReservationsPaginator = client.get_paginator("describe_capacity_reservations")
     describe_carrier_gateways_paginator: DescribeCarrierGatewaysPaginator = client.get_paginator("describe_carrier_gateways")
@@ -283,6 +285,7 @@ Usage::
 """
 from mypy_boto3_ec2.client import EC2Client
 from mypy_boto3_ec2.paginator import (
+    DescribeAddressesAttributePaginator,
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
     DescribeCarrierGatewaysPaginator,
@@ -430,6 +433,7 @@ __all__ = (
     "ConversionTaskCompletedWaiter",
     "ConversionTaskDeletedWaiter",
     "CustomerGatewayAvailableWaiter",
+    "DescribeAddressesAttributePaginator",
     "DescribeByoipCidrsPaginator",
     "DescribeCapacityReservationsPaginator",
     "DescribeCarrierGatewaysPaginator",
